emit method
Delivers frame to the hub, as the far end would.
Implementation
void emit(Object? frame) {
if (_incoming.isClosed) return;
_incoming.add(frame);
}
Delivers frame to the hub, as the far end would.
void emit(Object? frame) {
if (_incoming.isClosed) return;
_incoming.add(frame);
}